#include <fcntl.h>
#include <string.h>
#include <stdlib.h>
#include <stdio.h>
#include <sys/wait.h>
#include <sys/stat.h>
#include <arpa/inet.h>
#include <netdb.h>
#include <netinet/in.h>
#include <stdio.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <unistd.h>
#include <syslog.h>
#include <signal.h>
#include <errno.h>
#include <getopt.h>
#include <time.h>

#include "libbb_udhcp.h"

#include "csid/csid_dhcp.h"
#include "csman.h"

#define REMAINING 0
#define ABSOLUTE 1

#define MAXHOSTNAMELEN 31
struct lease_t {
	unsigned char chaddr[16];
	u_int32_t yiaddr;
	unsigned char hostname[MAXHOSTNAMELEN+1];
	u_int32_t expires;
};

#ifdef BB_VER
int dumpleases_main(int argc, char *argv[])
#else
int main(int argc, char *argv[])
#endif
{
	FILE *fp;
	int i, c, mode = REMAINING;
	long expires;
	char file[255] = "/var/lib/misc/udhcpd.leases";
	struct lease_t lease;
	struct in_addr addr;
	int csman_fd;
	unsigned int lease_cnt=0;
	unsigned int CSID_CLI_IP=CSID_S_DHCP_SVR_CLILIST_IP;
	unsigned int CSID_CLI_HOSTNAME=CSID_S_DHCP_SVR_CLILIST_HOSTNAME;
	unsigned int CSID_CLI_MAC=CSID_S_DHCP_SVR_CLILIST_MAC;
	unsigned int CSID_CLI_LEASETIME=CSID_S_DHCP_SVR_CLILIST_LEASETIME;
		
	static struct option options[] = {
		{"absolute", 0, 0, 'a'},
		{"remaining", 0, 0, 'r'},
		{"file", 1, 0, 'f'},
		{"help", 0, 0, 'h'},
		{0, 0, 0, 0}
	};

	while (1) {
		int option_index = 0;
		c = getopt_long(argc, argv, "arf:h", options, &option_index);
		if (c == -1) break;
		
		switch (c) {
		case 'a': mode = ABSOLUTE; break;
		case 'r': mode = REMAINING; break;
		case 'f':
			strncpy(file, optarg, 255);
			file[254] = '\0';
			break;
		case 'h':
			printf("Usage: dumpleases -f <file> -[r|a]\n\n");
			printf("  -f, --file=FILENAME             Leases file to load\n");
			printf("  -r, --remaining                 Interepret lease times as time remaing\n");
			printf("  -a, --absolute                  Interepret lease times as expire time\n");
			break;
		}
	}
			
	if (!(fp = fopen(file, "r"))) {
		perror("could not open input file");
		return 0;
	}
	
	csman_fd=open_csman(NULL, 0);
	if( csman_fd <0 ){
		perror("could not open Csman");
		return 0;	
	}
	
	printf("Mac Address       IP-Address      HOSTNAME    Expires %s\n", mode == REMAINING ? "in" : "at");  
	/*     "00:00:00:00:00:00 255.255.255.255 Wed Jun 30 21:49:08 1993" */
	
	lease_cnt=0;
	while (fread(&lease, sizeof(lease), 1, fp)) {

		for (i = 0; i < 6; i++) {
			printf("%02x", lease.chaddr[i]);
			if (i != 5) printf(":");
		}
				
		addr.s_addr = lease.yiaddr;
		printf(" %-15s", inet_ntoa(addr));
		printf(" %s", lease.hostname);		
		expires = ntohl(lease.expires);		
		printf(" ");
		if (mode == REMAINING) {
			if (!expires) printf("expired\n");
			else {
				
					
				write_csman(csman_fd, (unsigned int)(CSID_CLI_MAC+lease_cnt), (const void *)lease.chaddr, 6, 0);
				write_csman(csman_fd, (unsigned int)(CSID_CLI_IP+lease_cnt), (const void *)&addr, 4, 0);
				write_csman(csman_fd, (unsigned int)(CSID_CLI_HOSTNAME+lease_cnt), (const void *)lease.hostname, strlen(lease.hostname)+1, 0);
				write_csman(csman_fd, (unsigned int)(CSID_CLI_LEASETIME+lease_cnt), (const void *)&expires, sizeof(expires), 0);				 
								
				lease_cnt++;
					
				if (expires > 60*60*24) {
					printf("%ld days, ", expires / (60*60*24));
					expires %= 60*60*24;
				}
				if (expires > 60*60) {
					printf("%ld hours, ", expires / (60*60));
					expires %= 60*60;
				}
				if (expires > 60) {
					printf("%ld minutes, ", expires / 60);
					expires %= 60;
				}
				printf("%ld seconds\n", expires);				
			}
		} else printf("%s", ctime(&expires));

	}
	
	for(i=0;i<6;i++){
		lease.chaddr[i]=0;
	}

	addr.s_addr=0;
	strcpy(lease.hostname,"");
	expires=0;	
	
	write_csman(csman_fd, CSID_CLI_MAC+lease_cnt, (const void *)lease.chaddr, 6, 0);
	write_csman(csman_fd, CSID_CLI_IP+lease_cnt, (const void *)&addr, 4, 0);
	write_csman(csman_fd, CSID_CLI_HOSTNAME+lease_cnt, (const void *)lease.hostname, strlen(lease.hostname), 0);
	write_csman(csman_fd, CSID_CLI_LEASETIME+lease_cnt, (const void *)&expires, sizeof(expires), 0);
	
	close_csman(csman_fd);			
	
	fclose(fp);	
	return 0;
}
